@@ -315,8 +315,8 @@ class Status:
         :param position: 寻找图片的范围: (x1, y1, x2, y2)，默认为全部
         :return: 返回图片中心点坐标元组
         """
-        assert self.image_path
-        template_image = ddtank.cv2.imread(self.image_path + '/' + template_image_name + '.png')
+        assert self.image_path is not None
+        template_image = ddtank.cv2.imread(self.image_path + '/' + template_image_name + '.png', 0)
         x1, y1, x2, y2 = position
         image = self.capture()
         image = ddtank.cv2.cvtColor(image, ddtank.cv2.COLOR_BGR2GRAY)
